@@ -49,7 +49,7 @@
 #'   \item the total number of patients in the trial (\code{$totaln}),\cr
 #'   \item the total percentage of patients treated at the MTD (\code{$npercent}).
 #' }
-#' @author Hongying Sun, Li Tang, and Haitao Pan
+#' @author Xiaomeng Yuan, Chen Li, Hongying Sun, Li Tang and Haitao Pan
 #' @examples
 #' ### Drug-combination trial ###
 #'
@@ -61,7 +61,7 @@
 #'                           n.earlystop=12, startdose=c(1, 1), ntrial=100)
 #'
 #' @section Uses:
-#' This function uses \code{\link{get.boundary.comb.kb}} 
+#' This function uses \code{\link{get.boundary.comb.kb}}
 #'
 #' @family drug-combination functions
 #'
@@ -71,11 +71,12 @@
 #' Interval Design for Phase I Clinical Trials.
 #' \emph{Clinical Cancer Research}. 2017; 23:3994-4003.
 #' http://clincancerres.aacrjournals.org/content/23/15/3994.full-text.pdf
-#' 
-#' 
+#'
+#'
 #' Pan H, Lin R, Yuan Y. Keyboard design for phase I drug-combination trials.
 #' \emph{Contemporary Clinical Trials}. 2020.
 #' https://doi.org/10.1016/j.cct.2020.105972
+#' @import Rcpp methods graphics stats
 #' @export
 get.oc.comb.kb <- function(target, p.true, ncohort, cohortsize,
                            n.earlystop = 100, marginL = 0.05, marginR = 0.05,
@@ -120,15 +121,15 @@ get.oc.comb.kb <- function(target, p.true, ncohort, cohortsize,
                       dim(p.true)[1]), dim = c(dim(p.true), ntrial))
     dselect = matrix(rep(0, 2 * ntrial), ncol = 2)
 
-    total.incoherent.dlt = rep(0,ntrial)        
+    total.incoherent.dlt = rep(0,ntrial)
     total.incoherent.no.dlt = rep(0,ntrial)
     total.incoherent = rep(0,ntrial)
 
-    total.long.incoherent.dlt = rep(0,ntrial)       
+    total.long.incoherent.dlt = rep(0,ntrial)
     total.long.incoherent.no.dlt = rep(0,ntrial)
     total.long.incoherent = rep(0,ntrial)
 
-  
+
     temp = get.boundary.comb.kb(target, ncohort, cohortsize, cutoff.eli=0.95)$boundary
 
     b.e = temp[2, ]
@@ -139,13 +140,13 @@ get.oc.comb.kb <- function(target, p.true, ncohort, cohortsize,
         y <- matrix(rep(0, ndose), dim(p.true)[1], dim(p.true)[2])
         n <- matrix(rep(0, ndose), dim(p.true)[1], dim(p.true)[2])
 
-        incoherent.dlt = incoherent.no.dlt = 0   
-        long.incoherent.dlt = long.incoherent.no.dlt = 0   
+        incoherent.dlt = incoherent.no.dlt = 0
+        long.incoherent.dlt = long.incoherent.no.dlt = 0
         earlystop = 0
         d = startdose
         elimi = matrix(rep(0, ndose), dim(p.true)[1], dim(p.true)[2])
         for (pp in 1:ncohort) {
-            y.current <- y[d[1], d[2]]    
+            y.current <- y[d[1], d[2]]
 
             y[d[1], d[2]] = y[d[1], d[2]] + sum(runif(cohortsize) < p.true[d[1], d[2]])
             n[d[1], d[2]] = n[d[1], d[2]] + cohortsize
@@ -257,7 +258,7 @@ get.oc.comb.kb <- function(target, p.true, ncohort, cohortsize,
             dselect[trial, ] = c(99, 99)
         }
         else {
-            # select.mtd.comb is adapted from BOIN 
+            # select.mtd.comb is adapted from BOIN
  select.mtd.comb <- function (target, npts, ntox, cutoff.eli = 0.95, extrasafe = FALSE, offset = 0.05, mtd.contour = FALSE) {
     y = ntox
     n = npts
@@ -267,7 +268,7 @@ get.oc.comb.kb <- function(target, p.true, ncohort, cohortsize,
     elimi = matrix(0, dim(n)[1], dim(n)[2])
     if (extrasafe) {
         if (n[1, 1] >= 3) {
-            if (1 - pbeta(target, y[1, 1] + 1, n[1, 1] - y[1, 
+            if (1 - pbeta(target, y[1, 1] + 1, n[1, 1] - y[1,
                 1] + 1) > cutoff.eli - offset) {
                 elimi[, ] = 1
             }
@@ -276,7 +277,7 @@ get.oc.comb.kb <- function(target, p.true, ncohort, cohortsize,
     for (i in 1:dim(n)[1]) {
         for (j in 1:dim(n)[2]) {
             if (n[i, j] >= 3) {
-                if (1 - pbeta(target, y[i, j] + 1, n[i, j] - 
+                if (1 - pbeta(target, y[i, j] + 1, n[i, j] -
                   y[i, j] + 1) > cutoff.eli) {
                   elimi[i:dim(n)[1], j] = 1
                   elimi[i, j:dim(n)[2]] = 1
@@ -295,25 +296,25 @@ get.oc.comb.kb <- function(target, p.true, ncohort, cohortsize,
         phat.out = phat
         phat.out[n == 0] = NA
         phat[elimi == 1] = 1.1
-        phat = phat * (n != 0) + (1e-05) * (matrix(rep(1:dim(n)[1], 
-            each = dim(n)[2], len = length(n)), dim(n)[1], byrow = T) + 
-            matrix(rep(1:dim(n)[2], each = dim(n)[1], len = length(n)), 
+        phat = phat * (n != 0) + (1e-05) * (matrix(rep(1:dim(n)[1],
+            each = dim(n)[2], len = length(n)), dim(n)[1], byrow = T) +
+            matrix(rep(1:dim(n)[2], each = dim(n)[1], len = length(n)),
                 dim(n)[1]))
         phat[n == 0] = 10
-        selectdose = which(abs(phat - target) == min(abs(phat - 
+        selectdose = which(abs(phat - target) == min(abs(phat -
             target)), arr.ind = TRUE)
-        if (length(selectdose) > 2) 
+        if (length(selectdose) > 2)
             selectdose = selectdose[1, ]
         aa = function(x) as.numeric(as.character(x))
         if (mtd.contour == TRUE) {
-            selectdoses = cbind(row = 1:dim(n)[1], col = rep(99, 
+            selectdoses = cbind(row = 1:dim(n)[1], col = rep(99,
                 dim(n)[1]))
             for (k in dim(n)[1]:1) {
                 kn = n[k, ]
                 ky = y[k, ]
                 kelimi = elimi[k, ]
                 kphat = phat[k, ]
-                if (kelimi[1] == 1 || sum(n[kelimi == 0]) == 
+                if (kelimi[1] == 1 || sum(n[kelimi == 0]) ==
                   0) {
                   kseldose = 99
                 }
@@ -322,19 +323,19 @@ get.oc.comb.kb <- function(target, p.true, ncohort, cohortsize,
                   adm.index = which(adm.set == T)
                   y.adm = ky[adm.set]
                   n.adm = kn[adm.set]
-                  selectd = sort(abs(kphat[adm.set] - target), 
+                  selectd = sort(abs(kphat[adm.set] - target),
                     index.return = T)$ix[1]
                   kseldose = adm.index[selectd]
                 }
-                selectdoses[k, 2] = ifelse(is.na(kseldose), 99, 
+                selectdoses[k, 2] = ifelse(is.na(kseldose), 99,
                   kseldose)
-                if (k < dim(n)[1]) 
-                  if (selectdoses[k + 1, 2] == dim(n)[2]) 
+                if (k < dim(n)[1])
+                  if (selectdoses[k + 1, 2] == dim(n)[2])
                     selectdoses[k, 2] = dim(n)[2]
-                if (k < dim(n)[1]) 
-                  if (aa(selectdoses[k + 1, 2]) == dim(n)[2] & 
-                    aa(selectdoses[k + 1, 2]) == aa(selectdoses[k, 
-                      2])) 
+                if (k < dim(n)[1])
+                  if (aa(selectdoses[k + 1, 2]) == dim(n)[2] &
+                    aa(selectdoses[k + 1, 2]) == aa(selectdoses[k,
+                      2]))
                     selectdoses[k, 2] = 99
             }
         }
@@ -342,18 +343,18 @@ get.oc.comb.kb <- function(target, p.true, ncohort, cohortsize,
             selectdoses = matrix(99, nrow = 1, ncol = 2)
             selectdoses[1, ] = matrix(selectdose, nrow = 1)
         }
-        selectdoses = matrix(selectdoses[selectdoses[, 2] != 
+        selectdoses = matrix(selectdoses[selectdoses[, 2] !=
             99, ], ncol = 2)
         colnames(selectdoses) = c("DoseA", "DoseB")
     }
     if (mtd.contour == FALSE) {
         if (selectdoses[1, 1] == 99 && selectdoses[1, 2] == 99) {
             message("All tested doses are overly toxic. No MTD is selected! \n")
-            out = list(target = target, MTD = 99, p_est = matrix(NA, 
+            out = list(target = target, MTD = 99, p_est = matrix(NA,
                 nrow = dim(npts)[1], ncol = dim(npts)[2]))
         }
         else {
-            out = list(target = target, MTD = selectdoses, p_est = round(phat.out, 
+            out = list(target = target, MTD = selectdoses, p_est = round(phat.out,
                 2))
         }
         return(out)
@@ -361,18 +362,18 @@ get.oc.comb.kb <- function(target, p.true, ncohort, cohortsize,
     else {
         if (length(selectdoses) == 0) {
             message("All tested doses are overly toxic. No MTD is selected! \n")
-            out = list(target = target, MTD = 99, p_est = matrix(NA, 
+            out = list(target = target, MTD = 99, p_est = matrix(NA,
                 nrow = dim(npts)[1], ncol = dim(npts)[2]))
         }
         else {
-            out = list(target = target, MTD = selectdoses, p_est = round(phat.out, 
+            out = list(target = target, MTD = selectdoses, p_est = round(phat.out,
                 2))
         }
         return(out)
     }
 }
 
-            
+
             selcomb = select.mtd.comb(target, n, y, cutoff.eli, extrasafe, offset)
             dselect[trial, 1] = selcomb$MTD[1]
             dselect[trial, 2] = selcomb$MTD[2]
@@ -531,7 +532,7 @@ get.oc.comb.kb <- function(target, p.true, ncohort, cohortsize,
         ###
     }
 
-    out = list(name = "get.oc.comb.kb",  ## to identify object for summary.kb() function.
+    out = list(name = "get.oc.comb.kb",  ## to identify object for summary_kb() function.
                target = target,
                p.true = p.true,
                ncohort = ncohort,
